--[[

ARLFrame.lua

Frame functions for all of AckisRecipeList

]]--

ARL = AckisRecipeList
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList")

-- Calculates the total height of all the recipes in the child frame

local function ARL_CalculateChildHeight()

	local tempheight = 0
	RecipeFrame = AckisRecipeListRecipe1

	while ( RecipeFrame ~= nil ) do

		tempheight = RecipeFrame:GetHeight() + RecipeFrame.RecipeAquireText:GetHeight() + tempheight

		RecipeFrame = RecipeFrame.NextRecipe

	end

	return tempheight

end

-- Adds recipe text info to the frames
-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function ARL_OnClickExpandRecipe()

	if ( this.IsPushed == false ) then

		local RecipeText = nil 

		if ( AckisRecipeList.db.profile.sorting == "Skill" ) then

			RecipeText = string.match(this:GetText(), "%[.*%] %- (.*)")
				
		elseif ( AckisRecipeList.db.profile.sorting == "Name" ) then

			RecipeText = string.match(this:GetText(), "(.*) %- %[.*%]")

		end

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		this:SetDisabledTexture("Interface\\Buttons\\UI-MinusButton-Disabled")
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = true

		-- Show expanded text
		if ( ARL_MissingRecipeListing[ RecipeText ][ "Acquire" ] == nil ) then

			this.RecipeAquireText:SetText(L["NoObtain"])

		else

			this.RecipeAquireText:SetText( "    - " .. ARL_MissingRecipeListing[ RecipeText ][ "Acquire" ] )

		end

		this.RecipeAquireText:Show()

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, -1 * (this.RecipeAquireText:GetHeight() + 5) )

		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		this:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = false

		-- Hide expanded text
		this.RecipeAquireText:SetText("")
		this.RecipeAquireText:Hide()

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0)

		end

	end

	AckisRecipeListFrameScrollFrame:UpdateScrollChildRect()

	-- Show the scroll bar or not
	if ( ARL_CalculateChildHeight() < 355 ) then

		this.RecipeAquireText:SetWidth(320)
		AckisRecipeListFrameScrollFrameScrollBar:Hide()

	else

		this.RecipeAquireText:SetWidth(310)
		AckisRecipeListFrameScrollFrameScrollBar:Show()

	end

end

-- Adds recipe text info to the frames

local function ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedList, CurrentSpeciality)

	local OldFrame = nil
	local RecipeFrame = nil
	local RecipeCount = 1
	
	-- No sorting at all
	if ( SortedList == nil ) then

		local i = 1
		local RecipeName = next(ARL_MissingRecipeListing, nil)

		while ( RecipeName ~= nil ) do

			if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

				-- If the frame isn't created, then create it and set the parameters for it
				if ( not _G["AckisRecipeListRecipe" .. RecipeCount] ) then

					RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. RecipeCount, AckisRecipeListFrameScrollChild, "ClassTrainerSkillButtonTemplate")

					RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
					RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
					RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
					RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
					RecipeFrame:SetTextColor(1, 1, 1)
					RecipeFrame:SetScript("OnClick", ARL_OnClickExpandRecipe)
					RecipeFrame.IsPushed = false

					-- Create aquire text for the recipe
					RecipeFrame.RecipeAquireText = RecipeFrame:CreateFontString("AckisRecipeListRecipe" .. RecipeCount .. "Text", "DIALOG")

					RecipeFrame.RecipeAquireText:ClearAllPoints()
					RecipeFrame.RecipeAquireText:SetPoint("TOPLEFT", RecipeFrame, "BOTTOMLEFT", 20, 0)
					RecipeFrame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
					RecipeFrame.RecipeAquireText:SetTextColor(1, 1, 1)

				else

					RecipeFrame = _G["AckisRecipeListRecipe" .. RecipeCount]

				end

				-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
				if ( OldFrame ~= nil ) then

					OldFrame.NextRecipe = RecipeFrame

				end

				-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable
				if ( i == AckisRecipeList:GetNumMissingRecipes() ) then

					RecipeFrame.NextRecipe = nil
		
				else

					OldFrame = RecipeFrame

				end

				RecipeFrame:ClearAllPoints()

				-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
				if ( RecipeCount == 1 ) then

					RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrameScrollChild, "TOPLEFT", 5, -30)

				else

					RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (RecipeCount - 1), "BOTTOMLEFT", 0, -1)

				end

				RecipeFrame:SetText( RecipeName .. " - [" .. ARL_MissingRecipeListing[ RecipeName ][ "Level" ] .. "]" )

				RecipeFrame:Show()

				RecipeCount = RecipeCount + 1

			end

			i = i + 1

			-- Move on to the next entry in the table
			RecipeName = next(ARL_MissingRecipeListing, RecipeName)
	
		end

	-- Sorting (either by name or skill).  Scan through the sorted list
	else

		for i, RecipeName in ipairs(SortedList) do

			if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

				-- If the frame isn't created, then create it and set the parameters for it, otherwise use the current frame (recycle it)
				if ( not _G["AckisRecipeListRecipe" .. RecipeCount] ) then

					RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. RecipeCount, AckisRecipeListFrameScrollChild, "ClassTrainerSkillButtonTemplate")
					RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
					RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
					RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
					RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
					RecipeFrame:SetTextColor(1, 1, 1)
					RecipeFrame:SetScript("OnClick", ARL_OnClickExpandRecipe)
					RecipeFrame.IsPushed = false

					-- Create aquire text for the recipe
					RecipeFrame.RecipeAquireText = RecipeFrame:CreateFontString("AckisRecipeListRecipe" .. RecipeCount .. "Text", "DIALOG")

					RecipeFrame.RecipeAquireText:ClearAllPoints()
					RecipeFrame.RecipeAquireText:SetPoint("TOPLEFT", RecipeFrame, "BOTTOMLEFT", 20, 0)
					RecipeFrame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
					RecipeFrame.RecipeAquireText:SetTextColor(1, 1, 1)
					RecipeFrame.RecipeAquireText:SetJustifyH("LEFT")

				else

					-- Grab the frame from the global stack
					RecipeFrame = _G["AckisRecipeListRecipe" .. RecipeCount]

				end

				-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
				if ( OldFrame ~= nil ) then

					OldFrame.NextRecipe = RecipeFrame

				end

				-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable.
				if ( i == AckisRecipeList:GetNumMissingRecipes() ) then

					RecipeFrame.NextRecipe = nil
		
				else

					OldFrame = RecipeFrame

				end

				RecipeFrame:ClearAllPoints()

				-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
				if ( RecipeCount == 1 ) then

					RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrameScrollChild, "TOPLEFT", 5, -30)

				else

					RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (RecipeCount - 1), "BOTTOMLEFT", 0, -1)

				end

				if ( AckisRecipeList.db.profile.sorting == "Skill") then

					RecipeFrame:SetText("[" .. ARL_MissingRecipeListing[ RecipeName ][ "Level" ] .. "] - " .. RecipeName)
				
				elseif ( AckisRecipeList.db.profile.sorting == "Name") then

					RecipeFrame:SetText(RecipeName .. " - [" .. ARL_MissingRecipeListing[ RecipeName ][ "Level" ] .. "]")

				end
				
				RecipeFrame:Show()

				RecipeCount = RecipeCount + 1

			end

		end

	end

	-- Show the scroll bar or not
	if ( ARL_CalculateChildHeight() < 355 ) then

		AckisRecipeListFrameScrollFrameScrollBar:Hide()

	else

		AckisRecipeListFrameScrollFrameScrollBar:Show()

	end

end

-- Closes the frame and cleans sets everything that was displayed to nil

local function ARL_CloseFrame()

--[[
	AckisRecipeListTab1:SetText("")
	AckisRecipeListTab1:Hide()
	AckisRecipeListTab2:SetText("")
	AckisRecipeListTab2:Hide()
	AckisRecipeListTab3:SetText("")
	AckisRecipeListTab3:Hide()
]]--

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1

	-- Clear x number of entries for all missing recipes
	while ( RecipeFrame ~= nil ) do

		--RecipeFrame.RecipeAquireText:ClearAllPoints()
		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame:SetText("")
		RecipeFrame:Hide()

		if ( RecipeFrame.IsPushed == true ) then

			RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
			RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
			RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
			RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

			RecipeFrame.IsPushed = false

		end

		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame = RecipeFrame.NextRecipe

	end

	AckisRecipeListFrame:Hide()

end

-- Adds tabs to the gui

local function ARL_AddTabs(Profession)

	-- Assumption is that at most 5 tabs will be needed: Cooking, First Aid, Beast Skills, Profession 1 and Profession 2

	if ( not AckisRecipeListTab1 ) then

		AckisRecipeListTab1 = CreateFrame("Button", "AckisRecipeListTab1", AckisRecipeListFrame, "CharacterFrameTabButtonTemplate")

		AckisRecipeListTab1:ClearAllPoints()
		AckisRecipeListTab1:SetPoint("CENTER", AckisRecipeListFrame, "BOTTOMLEFT", 60, -10)
		AckisRecipeListTab1:RegisterForClicks("LeftButtonUp")
		--AckisRecipeListTab1:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end)
		--AckisRecipeListTab1:Enable()
		AckisRecipeListTab1:Disable()
		AckisRecipeListTab1:SetTextColor(1, 1, 1)

	end

	AckisRecipeListTab1:SetText(Profession)
	AckisRecipeListTab1:Show()

	if ( not AckisRecipeListTab2 ) then

		AckisRecipeListTab2 = CreateFrame("Button", "AckisRecipeListTab2", AckisRecipeListFrame, "CharacterFrameTabButtonTemplate")

		AckisRecipeListTab2:ClearAllPoints()
		AckisRecipeListTab2:SetPoint("LEFT", AckisRecipeListTab1, "RIGHT", 0, 0)
		AckisRecipeListTab2:RegisterForClicks("LeftButtonUp")
		--AckisRecipeListTab2:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end)
		--AckisRecipeListTab2:Enable()
		AckisRecipeListTab2:Disable()
		AckisRecipeListTab2:SetTextColor(1, 1, 1)

	end

	AckisRecipeListTab2:SetText(BTS["Cooking"])
	AckisRecipeListTab2:Show()

	if ( not AckisRecipeListTab3 ) then

		AckisRecipeListTab3 = CreateFrame("Button", "AckisRecipeListTab2", AckisRecipeListFrame, "CharacterFrameTabButtonTemplate")

		AckisRecipeListTab3:ClearAllPoints()
		AckisRecipeListTab3:SetPoint("LEFT", AckisRecipeListTab2, "RIGHT", 0, 0)
		AckisRecipeListTab3:RegisterForClicks("LeftButtonUp")
		--AckisRecipeListTab3:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end)
		--AckisRecipeListTab3:Enable()
		AckisRecipeListTab3:Disable()
		AckisRecipeListTab3:SetTextColor(1, 1, 1)

	end

	AckisRecipeListTab3:SetText(BTS["First Aid"])
	AckisRecipeListTab3:Show()

end

-- Adds a button to the trade skill/skillet/crafting skill window allowing you to scan

function ARL_AddScanButton()

	if ( not AckisRecipeListFrameScanButton ) then

		AckisRecipeListFrameScanButton = CreateFrame("Button", "AckisRecipeListFrameScanButton", UIParent, "UIPanelButtonTemplate")

	end

end

-- Allows the scan button to close the scan window

local function ScanButtonClick()

	if ( AckisRecipeListFrameScanButton.PushedOnce == true ) then

		AckisRecipeListFrameScanButton.PushedOnce = false
		AckisRecipeListFrame:Hide()

	else

		if ( AckisRecipeList.db.profile.usegui == true ) then

			AckisRecipeListFrameScanButton.PushedOnce = true

		end

		AckisRecipeList:AckisRecipeList_Command()

	end

end

-- Shows the scan button

function ARL:ShowScanButton()

	-- Add to Skillet interface
	if ( Skillet and Skillet:IsActive() and GetCraftName() ~= L["Beast Training"] ) then

		AckisRecipeListFrameScanButton:SetParent(SkilletFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:SetTextColor(1, 0.8, 0)
		Skillet:AddButtonToTradeskillWindow(AckisRecipeListFrameScanButton)

	elseif (ATSWFrame and GetCraftName() ~= L["Beast Training"]) then

		AckisRecipeListFrameScanButton:SetParent(ATSWFrame)
		AckisRecipeListFrameScanButton:Show()
		AckisRecipeListFrameScanButton:ClearAllPoints()
		AckisRecipeListFrameScanButton:SetPoint("RIGHT", ATSWOptionsButton, "LEFT", 0, 0)
		AckisRecipeListFrameScanButton:SetFrameStrata("DIALOG")
		AckisRecipeListFrameScanButton:SetTextColor(ATSWOptionsButton:GetTextColor())
		AckisRecipeListFrameScanButton:SetHeight(ATSWOptionsButton:GetHeight())

	else

		-- Anchor to trade window
		if ( ARL_SkillType == "Trade" ) then

			AckisRecipeListFrameScanButton:SetParent(TradeSkillFrame)
			AckisRecipeListFrameScanButton:Show()
			AckisRecipeListFrameScanButton:ClearAllPoints()
			AckisRecipeListFrameScanButton:SetPoint("TOP", TradeSkillFrame, "BOTTOMRIGHT", -85, 75)

		-- Anchor to crafting window
		elseif ( ARL_SkillType == "Craft" ) then

			AckisRecipeListFrameScanButton:SetParent(CraftFrame)
			AckisRecipeListFrameScanButton:Show()
			AckisRecipeListFrameScanButton:ClearAllPoints()
			AckisRecipeListFrameScanButton:SetPoint("TOP", CraftFrame, "BOTTOMRIGHT", -85, 75)

		end

		AckisRecipeListFrameScanButton:SetFrameStrata("DIALOG")
		AckisRecipeListFrameScanButton:SetTextColor(1, 1, 1)

	end

	AckisRecipeListFrameScanButton:SetWidth(100)
	AckisRecipeListFrameScanButton:SetHeight(24)
	AckisRecipeListFrameScanButton:RegisterForClicks("LeftButtonUp")
	AckisRecipeListFrameScanButton.PushedOnce = false
	AckisRecipeListFrameScanButton:SetScript("OnClick", function() ScanButtonClick() end)
	AckisRecipeListFrameScanButton:SetText(L["Scan Skills"])
	AckisRecipeListFrameScanButton:Enable()

end

-- Hides the scan button

function ARL:HideScanButton()

	if AckisRecipeListFrameScanButton then

		AckisRecipeListFrameScanButton:Hide()

	end

end

-- Creates the initial frame to display recipes into

function ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	if ( not AckisRecipeListFrame ) then

		-- Create the main frame
		AckisRecipeListFrame = CreateFrame("Frame", "AckisRecipeListFrame", UIParent)

		AckisRecipeListFrame:SetFrameStrata("DIALOG")
		AckisRecipeListFrame:SetWidth(384)
		AckisRecipeListFrame:SetHeight(430)
		AckisRecipeListFrame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
		AckisRecipeListFrame:SetBackdropColor(0, 0, 0)
		AckisRecipeListFrame:EnableMouse(true)
		AckisRecipeListFrame:EnableKeyboard(true)
		AckisRecipeListFrame:SetMovable(true)
		AckisRecipeListFrame:SetScript("OnMouseDown", function() AckisRecipeListFrame:StartMoving() end)
		AckisRecipeListFrame:SetScript("OnHide", function() ARL_CloseFrame() end)
		AckisRecipeListFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)
--[[
		AckisRecipeListBottomFrame = CreateFrame("Frame", "AckisRecipeListBottomFrame", AckisRecipeListFrame)

		AckisRecipeListBottomFrame:ClearAllPoints()
		AckisRecipeListBottomFrame:SetPoint("BOTTOM", AckisRecipeListFrame, "BOTTOM", 0, 0)
		AckisRecipeListBottomFrame:SetWidth(384)
		AckisRecipeListBottomFrame:SetHeight(40)
		AckisRecipeListBottomFrame:EnableMouse(true)
		AckisRecipeListBottomFrame:SetMovable(true)
		AckisRecipeListBottomFrame:SetScript("OnMouseDown", function()	AckisRecipeListFrame:StartMoving()	end)
		AckisRecipeListBottomFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

		AckisRecipeListBottomFrameHeaderFrameTexture = AckisRecipeListBottomFrame:CreateTexture("AckisRecipeListBottomFrameHeaderFrameTexture", "ARTWORK")

		AckisRecipeListBottomFrameHeaderFrameTexture:SetTexture("Interface\\TradeSkillFrame\\UI-TradeSkill-SkillBorder")
		AckisRecipeListBottomFrameHeaderFrameTexture:SetWidth(384)
		AckisRecipeListBottomFrameHeaderFrameTexture:SetHeight(64)
		AckisRecipeListBottomFrameHeaderFrameTexture:ClearAllPoints()
		AckisRecipeListBottomFrameHeaderFrameTexture:SetPoint("TOP", AckisRecipeListBottomFrame, "TOP", 0, 0)
]]--

		-- Add header frame
		AckisRecipeListFrameHeaderFrame = CreateFrame("Frame", "AckisRecipeListFrameHeaderFrame", AckisRecipeListFrame)

		AckisRecipeListFrameHeaderFrame:SetWidth(192)
		AckisRecipeListFrameHeaderFrame:SetHeight(32)
		AckisRecipeListFrameHeaderFrame:ClearAllPoints()
		AckisRecipeListFrameHeaderFrame:SetPoint("TOP", AckisRecipeListFrame, "TOP", 0, 6)
		AckisRecipeListFrameHeaderFrame:EnableMouse(true)
		AckisRecipeListFrameHeaderFrame:SetMovable(true)
		AckisRecipeListFrameHeaderFrame:SetScript("OnMouseDown", function()	AckisRecipeListFrame:StartMoving()	end)
		AckisRecipeListFrameHeaderFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

		-- Add texture to the header frame
		AckisRecipeListFrameHeaderFrameTexture = AckisRecipeListFrameHeaderFrame:CreateTexture("AckisRecipeListFrameHeaderFrameTexture", "ARTWORK")

		AckisRecipeListFrameHeaderFrameTexture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
		AckisRecipeListFrameHeaderFrameTexture:SetWidth(384)
		AckisRecipeListFrameHeaderFrameTexture:SetHeight(64)
		AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints()
		AckisRecipeListFrameHeaderFrameTexture:SetPoint("TOP", AckisRecipeListFrameHeaderFrame, "TOP", 0, 5)

		-- Add text to header frame
		AckisRecipeListFrameHeaderFrameText = AckisRecipeListFrameHeaderFrame:CreateFontString("AckisRecipeListFrameHeaderFrameText", "ARTWORK")

		AckisRecipeListFrameHeaderFrameText:SetFontObject(GameFontNormal)
		AckisRecipeListFrameHeaderFrameText:ClearAllPoints()
		AckisRecipeListFrameHeaderFrameText:SetPoint("CENTER", AckisRecipeListFrameHeaderFrame, "CENTER", 0, 0)
		AckisRecipeListFrameHeaderFrameText:SetText(ARLTitle)

		-- Add close button
		AckisRecipeListFrameCloseButton = CreateFrame("Button", "AckisRecipeListFrameCloseButton", AckisRecipeListFrame, "UIPanelButtonTemplate")

		AckisRecipeListFrameCloseButton:SetFrameStrata("DIALOG")
		AckisRecipeListFrameCloseButton:SetWidth(100)
		AckisRecipeListFrameCloseButton:SetHeight(24)
		AckisRecipeListFrameCloseButton:ClearAllPoints()
		AckisRecipeListFrameCloseButton:SetPoint("BOTTOMRIGHT", AckisRecipeListFrame, -10, 10)
		AckisRecipeListFrameCloseButton:RegisterForClicks("LeftButtonUp")
		AckisRecipeListFrameCloseButton:SetScript("OnClick", function() ARL_CloseFrame() end )
		AckisRecipeListFrameCloseButton:SetFont("GameFontHighlightSmall",12)
		AckisRecipeListFrameCloseButton:Enable()
		AckisRecipeListFrameCloseButton:SetTextColor(1, 1, 1)
		AckisRecipeListFrameCloseButton:SetText(L["Close"])

		-- Add a "close with x" button
		AckisRecipeListFrameXButton = CreateFrame("Button", "AckisRecipeListFrameXButton", AckisRecipeListFrame, "UIPanelCloseButton")

		AckisRecipeListFrameXButton:ClearAllPoints()
		AckisRecipeListFrameXButton:SetPoint("TOPRIGHT", AckisRecipeListFrame, "TOPRIGHT", 0, 0)
		AckisRecipeListFrameXButton:RegisterForClicks("LeftButtonUp")
		AckisRecipeListFrameXButton:SetScript("OnClick", function() ARL_CloseFrame() end )
		AckisRecipeListFrameXButton:Enable()

		-- Adds scroll frame to mainframe
		AckisRecipeListFrameScrollFrame = CreateFrame("ScrollFrame", "AckisRecipeListFrameScrollFrame", AckisRecipeListFrame, "UIPanelScrollFrameTemplate")
	
		AckisRecipeListFrameScrollFrame:ClearAllPoints()
		AckisRecipeListFrameScrollFrame:SetPoint("TOPLEFT", AckisRecipeListFrame, "TOPLEFT", 10, -30)
		AckisRecipeListFrameScrollFrame:SetHeight(360)
		AckisRecipeListFrameScrollFrame:SetWidth(344)
		AckisRecipeListFrameScrollFrame:EnableMouseWheel(true)
		AckisRecipeListFrameScrollFrame:EnableMouse(true)

		AckisRecipeListFrameScrollChild = CreateFrame("Frame", "AckisRecipeListFrameScrollChild", AckisRecipeListFrameScrollFrame)

		AckisRecipeListFrameScrollChild:ClearAllPoints()
		AckisRecipeListFrameScrollChild:SetPoint("TOPLEFT", AckisRecipeListScrollFrame, "TOPLEFT", 10, -30)
		AckisRecipeListFrameScrollChild:SetWidth(340)
		AckisRecipeListFrameScrollChild:SetHeight(355)
		AckisRecipeListFrameScrollChild:EnableMouseWheel(true)
		AckisRecipeListFrameScrollChild:EnableMouse(true)

		AckisRecipeListFrameScrollFrame:SetScrollChild(AckisRecipeListFrameScrollChild)

		-- Add progress bar to frame
		AckisRecipeListFrameProgressBar = CreateFrame("StatusBar", "AckisRecipeListFrameProgressBar", AckisRecipeListFrame)
		
		AckisRecipeListFrameProgressBar:SetWidth(260)
		AckisRecipeListFrameProgressBar:SetHeight(20)
		AckisRecipeListFrameProgressBar:ClearAllPoints()
		AckisRecipeListFrameProgressBar:SetPoint("BOTTOMLEFT", AckisRecipeListFrame, 10, 10)
		AckisRecipeListFrameProgressBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
		AckisRecipeListFrameProgressBar:SetOrientation("HORIZONTAL")
		AckisRecipeListFrameProgressBar:SetStatusBarColor(0.25, 0.25, 0.75)

		AckisRecipeListFrameProgressBarBorder = CreateFrame("Button", "AckisRecipeListFrameProgressBarBorder", AckisRecipeListFrameProgressBar)

		-- Add border to status bar
		AckisRecipeListFrameProgressBarBorder:SetNormalTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-BarBorder")
		AckisRecipeListFrameProgressBarBorder:SetWidth(270)
		AckisRecipeListFrameProgressBarBorder:SetHeight(40)
		AckisRecipeListFrameProgressBarBorder:ClearAllPoints()
		AckisRecipeListFrameProgressBarBorder:SetPoint("CENTER", AckisRecipeListFrameProgressBar, "CENTER", 0, 0)

		AckisRecipeListFrameProgressBarText = AckisRecipeListFrameProgressBar:CreateFontString("AckisRecipeListFrameProgressBarText", "ARTWORK")

		-- Add text to header frame
		AckisRecipeListFrameProgressBarText:SetFontObject(GameFontHighlightSmall)
		AckisRecipeListFrameProgressBarText:ClearAllPoints()
		AckisRecipeListFrameProgressBarText:SetPoint("CENTER", AckisRecipeListFrameProgressBar, "CENTER", 0, 0)

		-- Adds Profession header text
		ARLProfessionText = AckisRecipeListFrameScrollChild:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		ARLProfessionText:SetTextColor(1.0, 1.0, 0.1)
		ARLProfessionText:ClearAllPoints()
		ARLProfessionText:SetPoint("TOP", 0, 0)

	end

	AckisRecipeListFrame:ClearAllPoints()

	-- Anchor the frame to a specific window

	-- Anchors to Skillet window
	if ( Skillet and Skillet:IsActive() ) then

		AckisRecipeListFrame:SetPoint("LEFT", SkilletFrame, "RIGHT", 0, 0)

	-- Anchor to ATSW
	elseif ( ATSWFrame ) then

		AckisRecipeListFrame:SetPoint("RIGHT", ATSWFrame, "RIGHT", 345, 30)

	-- Anchor to trade skill window
	elseif ( ARL_SkillType == "Trade" ) then

		AckisRecipeListFrame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30)

	-- Anchor to crafting window
	elseif ( ARL_SkillType == "Craft" ) then

		AckisRecipeListFrame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)

	-- Nothing found to anchor, just put it up in the middle
	else

		AckisRecipeListFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)

	end

	-- Set the text / status bar display  of the progress bar
	AckisRecipeListFrameProgressBar:SetMinMaxValues(0, ARL_NumberOfRecipes)
	AckisRecipeListFrameProgressBar:SetValue(ARL_FoundRecipes)
	AckisRecipeListFrameProgressBarText:SetText( ARL_FoundRecipes .. " \\ " .. ARL_NumberOfRecipes .. " - " .. math.floor( ARL_FoundRecipes / ARL_NumberOfRecipes * 100 ) .. "%" )

	if ( CurrentSpeciality == "" ) then

		ARLProfessionText:SetText(CurrentProfession)

	else

		ARLProfessionText:SetText(CurrentProfession .. " - " .. CurrentSpeciality)

	end

	--AckisRecipeListBottomFrame:Show()
	AckisRecipeListFrame:Show()

	-- Add frame elements

	--ARL_AddTabs(CurrentProfession)

	ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

end

