﻿--[[
****************************************************************************************
AckisRecipeList v0.633
4 February 2008

Author: Ackis on Gurubashi US Horde
****************************************************************************************

Please see Wowace.com for more information.

****************************************************************************************
]]
--/print GetMouseFocus()
local Crayon	= AceLibrary("Crayon-2.0")
local BTS		= AceLibrary("Babble-Tradeskill-2.2")
local BFAC		= AceLibrary("Babble-Faction-2.2")
local BCLASS	= AceLibrary("Babble-Class-2.2")
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList")

-- Local Constants

AckisRecipeList = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")
ARL = AckisRecipeList
ARLTitle = "Ackis Recipe List 0.633"

-- Local global variables

--Our global variables
ARL_RecipeListing = nil
ARL_MissingRecipeListing = nil
ARL_SkillType = nil
ARL_FoundRecipes = nil
ARL_NumberOfRecipes = nil
AckisRecipeListFrame = nil

-- Command line options for the mod.
-- Allows you to filter which recipes to display based on faction, class, profession speciality, rare raid recipes, and current/max skill level

local command_options = {
    type = "group",
    args =
	{
		scan =
		{
			type = "execute",
			name = "Scan",
			desc = L["SCAN"],
			func = "AckisRecipeList_Command",
			order = 1,
		},
    	title =
		{
    		type = "header",
    		name = L["ARL_CONFIG_HEADER"],
    		order = 3,
    	},
		display =
		{
			type = "group",
			name = "Display",
			desc = L["DISPLAY_OPTIONS"],
			order = 4,
			args =
			{
				usegui =
				{
					name	= "Use GUI",
					desc	= L["GUI_TOGGLE"],
					type	= "toggle",
					get		= function() return AckisRecipeList.db.profile.usegui end,
					set		= function() AckisRecipeList.db.profile.usegui = not AckisRecipeList.db.profile.usegui end,
					order	= 1,
				}
			}
		},
        filter =
		{
            type = "group",
			name = "Filter",
			desc = L["FILTER_OPTIONS"],
			order = 5,
			args =
			{
				factions =
				{
                    name	= "Faction",
                    desc	= L["FACTION_TOGGLE"],
                    type	= "toggle",
                    get		= function() return AckisRecipeList.db.profile.faction end,
                    set		= function() AckisRecipeList.db.profile.faction = not AckisRecipeList.db.profile.faction end,
                    order	= 1,
				},
				PVP =
				{
                    name	= "PVP",
                    desc	= L["PVP_TOGGLE"],
                    type	= "toggle",
                    get		= function() return AckisRecipeList.db.profile.pvp end,
                    set		= function() AckisRecipeList.db.profile.pvp = not AckisRecipeList.db.profile.pvp end,
                    order	= 2,
				},
				classes =
				{
                    name      = "Classes",
                    desc      = L["CLASS_TOGGLE"],
                    type      = "toggle",
                    get       = function() return AckisRecipeList.db.profile.classes end,
                    set       = function() AckisRecipeList.db.profile.classes = not AckisRecipeList.db.profile.classes end,
                    order     = 3,
				},
				specialities =
				{
                    name      = "Specialities",
                    desc      = L["SPECIALITY_TOGGLE"],
                    type      = "toggle",
                    get       = function() return AckisRecipeList.db.profile.specialities end,
                    set       = function() AckisRecipeList.db.profile.specialities = not AckisRecipeList.db.profile.specialities end,
                    order     = 4,
				},
				raid =
				{
                    name      = "Raid",
                    desc      = L["RAID_TOGGLE"],
                    type      = "toggle",
                    get       = function() return AckisRecipeList.db.profile.raid end,
                    set       = function() AckisRecipeList.db.profile.raid = not AckisRecipeList.db.profile.raid end,
                    order     = 5,
				},
				skill =
				{
                    name      = "Skill",
                    desc      = L["SKILL_TOGGLE"],
                    type      = "toggle",
                    get       = function() return AckisRecipeList.db.profile.skill end ,
                    set       = function() AckisRecipeList.db.profile.skill = not AckisRecipeList.db.profile.skill end,
                    order     = 6,
				}
			}
		},
		sorting =
		{
			name      = "Sort",
			desc      = L["SORT_OPTIONS"],
			type      = "text",
			validate  = { L["SORT_Name"], L["SORT_Skill"], L["SORT_Unsorted"] },
			get       = function() return AckisRecipeList.db.profile.sorting end,
			set       = function(name) ARL:ToggleAllSorting(name) end,
			order     = 6,
		}
	}
}


--[[

	Saved variables functions

]]--

-- Initialize the database and set the default options

ARL:RegisterDB("AckisRecipeListDB", "AckisRecipeListDBPC")

-- Set default options, which are to include everything in the scan
ARL:RegisterDefaults("profile",
	{
    faction = true,
	classes = false,
	pvp = true,
	specialities = false,
	raid = true,
	skill = true,
	usegui = true,
	sorting = "Skill",
	}
)

-- Toggles the boolean value of the AllFactions variable in the database.

function ARL:ToggleAllSorting(NewValue)

	if ( NewValue == L["SORT_Name"]) then

		self.db.profile.sorting = "Name"

	elseif ( NewValue == L["SORT_Skill"]) then

		self.db.profile.sorting = "Skill"

	elseif ( NewValue == L["SORT_Unsorted"]) then

		self.db.profile.sorting = "Unsorted"

	end

end

--[[

	Reset functions

]]--

-- Empties the RecipeList table

local function ARL_ResetRecipeList()

	if ( ARL_RecipeListing ~= nil) then

		local CurrentRecipe = next(ARL_RecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			ARL_RecipeListing[ CurrentRecipe ][ "Level" ] = nil
			ARL_RecipeListing[ CurrentRecipe ][ "Acquire" ] = nil
			ARL_RecipeListing[ CurrentRecipe ][ "Speciality" ] = nil		
			ARL_RecipeListing[ CurrentRecipe ][ "Known" ] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(ARL_RecipeListing, CurrentRecipe)

			ARL_RecipeListing[ OldRecipe ] = nil

		end

	end

	ARL_RecipeListing = nil

end

-- Empties the MissingRecipeList table

local function ARL_ResetMissingRecipeList()

	if ( ARL_MissingRecipeListing ~= nil) then

		local CurrentRecipe = next(ARL_MissingRecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			ARL_MissingRecipeListing[ CurrentRecipe ][ "Level" ] = nil
			ARL_MissingRecipeListing[ CurrentRecipe ][ "Acquire" ] = nil
			ARL_MissingRecipeListing[ CurrentRecipe ][ "Speciality" ] = nil		
			ARL_MissingRecipeListing[ CurrentRecipe ][ "Known" ] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(ARL_MissingRecipeListing, CurrentRecipe)

			ARL_MissingRecipeListing[ OldRecipe ] = nil

		end

	end

	ARL_MissingRecipeListing = nil

end

-- Reset all variables

local function ARL_ResetVariables()

	ARL_ResetRecipeList()
	--ARL_ResetMissingRecipeList()

	ARL_SkillType = nil
	ARL_FoundRecipes = nil
	ARL_NumberOfRecipes = nil

end

-- Initializes the initial recipe array, reseting it completely.

function ARL:ARL_InitializeRecipeArray()

	-- Reset namespace to be empty
	ARL_RecipeListing = {}
	ARL_MissingRecipeListing = {}
  
	-- Sets the total number of recipes to 0.
	ARL_NumberOfRecipes = 0

	-- Sets the number of found recipes to 0.
	ARL_FoundRecipes = 0

end

--[[

	Initialization functions

]]--

-- When the add-on is enabled, register slash commands, and which events to watch

function ARL:OnEnable()

	-- Add slash commands
	self:RegisterChatCommand(L["LONG_COMMAND"], L["SHORT_COMMAND"], command_options)

	-- Make addon respond to the tradeskill and crafting windows being shown
	self:RegisterEvent("TRADE_SKILL_SHOW")
	self:RegisterEvent("CRAFT_SHOW")

	-- Addon responds to tradeskill and crafting windows being closed.
	self:RegisterEvent("CRAFT_CLOSE")
	self:RegisterEvent("TRADE_SKILL_CLOSE")

	--Create the button now for later use
	ARL_AddScanButton()
	ARL:HideScanButton()

	--Allows ARL to be closed with the Escape key
	tinsert(UISpecialFrames, "AckisRecipeListFrame")

end

-- Hides the frame if the mod gets disabled

function ARL:OnDisable()

	ARL_ResetVariables()

	if AckisRecipeListFrame then

		AckisRecipeListFrame:Hide()

	end

	-- Removes ARL entry
	tremove(UISpecialFrames, "AckisRecipeListFrame");

end

-- Watch for the trade skill window to be shown, add all specific trade skills to an array, then scan the trade skill window for all recipes.

function ARL:TRADE_SKILL_SHOW()

	ARL_SkillType = "Trade"
	ARL:ShowScanButton()

end

-- Clean up tables from memory when trade skill window is closed

function ARL:TRADE_SKILL_CLOSE()

	ARL_ResetVariables()
	ARL:HideScanButton()

end

-- Watch for the craft skill window to be shown, add all specific trade skills to an array, then scan the craft skill window for all recipes.

function ARL:CRAFT_SHOW()

	ARL_SkillType = "Craft"
	ARL:ShowScanButton()

end

-- Clean up tables from memory when craft window is closed

function ARL:CRAFT_CLOSE()

	ARL_ResetVariables()
	ARL:HideScanButton()

end

--[[

	Tradeskill functions

]]--

-- Adds a specifc recipe to the recipe list array.  Also provides information regarding recipe level, if there is any trade skill recipe speciality, how to aquire the recipe, and if the recipe is known or not.

function ARL:addTradeSkill(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, VendorInfo, RecipeKnown)

	-- Creates a table in the ARL_RecipeListing table storing all information about a recipe
	ARL_RecipeListing[ RecipeName ] = {}
	ARL_RecipeListing[ RecipeName ][ "Level" ] = RecipeLevel
	ARL_RecipeListing[ RecipeName ][ "Acquire" ] = RecipeAquire

	if (RecipeSpeciality == nil) then

		ARL_RecipeListing[ RecipeName ][ "Speciality" ] = {}

	else

		ARL_RecipeListing[ RecipeName ][ "Speciality" ] = RecipeSpeciality

	end

	if (VendorInfo == nil) then

		ARL_RecipeListing[ RecipeName ][ "VendorInfo" ] = {}

	else

		ARL_RecipeListing[ RecipeName ][ "VendorInfo" ] = VendorInfo

	end

	if (RecipeKnown == nil) then

		ARL_RecipeListing[ RecipeName ][ "Known" ] = false

	else

		ARL_RecipeListing[ RecipeName ][ "Known" ] = RecipeKnown

	end

	-- Increment the total number of recipes added to the list
	ARL_NumberOfRecipes = ARL_NumberOfRecipes + 1

end

-- Modifies recipe array if a recipe is found, setting the Known flag as true.

function ARL:foundTradeSkill(RecipeName)

	ARL_RecipeListing[ RecipeName ][ "Known" ] = true

	-- Increase found count
	ARL_FoundRecipes = ARL_FoundRecipes + 1

end

-- Checks to see if a recipe is known or not.  If the recipe is not in the database, output it to chat.

function ARL:CheckRecipe(RecipeName)

	if ( ARL_RecipeListing[ RecipeName ] ) then

		-- Update array that recipe was found
		ARL:foundTradeSkill(RecipeName)
	
	else

		-- Notify users in chat that skill is missing from the database.
		ARL:printMissingSkill(RecipeName)

	end

end

-- Check to see if recipe should be displayed or not

function ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)
--DEFAULT_CHAT_FRAME:AddMessage(RecipeName)
	-- Variable to determine if recipe is to be displayed or not, assume yes
	local displayRecipe = true

	-- Display all skill levels
	if (ARL_MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then

		if (not self.db.profile.skill) then

			displayRecipe = false

		end

	end

	if (ARL_MissingRecipeListing[RecipeName]["Speciality"] ~= nil) then

		for i, CurrentCheck in pairs(ARL_MissingRecipeListing[RecipeName]["Speciality"]) do

			-- Display hard to obtain raid recipes
			if ( not self.db.profile.raid ) then

				if ( CurrentCheck == L["Raid"]) then

					displayRecipe = false

				end

			end

			-- Display all faction recipes
			if ( not self.db.profile.faction ) then

				local playerFaction, _ = UnitFactionGroup("player")

				-- Make sure it's Horde or Alliance
				if (CurrentCheck == BFAC["Horde"]) or
				(CurrentCheck == BFAC["Alliance"]) then

					if (CurrentCheck ~= playerFaction) then
					
						displayRecipe = false

					end

				end

			end

			-- Display all class type recipes
			if ( not self.db.profile.classes ) then

				local playerClass, _ = UnitClass("player")

				-- Make sure it's a class
				if (CurrentCheck == BCLASS["Warlock"]) or 
				(CurrentCheck == BCLASS["Warrior"]) or 
				(CurrentCheck == BCLASS["Hunter"]) or 
				(CurrentCheck == BCLASS["Mage"]) or 
				(CurrentCheck == BCLASS["Priest"]) or 
				(CurrentCheck == BCLASS["Druid"]) or 
				(CurrentCheck == BCLASS["Paladin"]) or 
				(CurrentCheck == BCLASS["Shaman"]) or 
				(CurrentCheck == BCLASS["Rogue"]) then

					if (CurrentCheck ~= playerClass ) then
					
						displayRecipe = false

					end

				end

			end

			-- Display all specialities (ie: Primal Mooncloth, Spellcloth, etc.)
			if ( not self.db.profile.specialities ) then

				if (CurrentProfession == BTS["Blacksmithing"]) then

					if (CurrentCheck == BTS["Armorsmith"]) or
						(CurrentCheck == BTS["Master Axesmith"]) or
						(CurrentCheck == BTS["Master Hammersmith"]) or
						(CurrentCheck == BTS["Master Swordsmith"]) or
						(CurrentCheck == BTS["Weaponsmith"]) then

							if (CurrentCheck ~= CurrentSpeciality ) then

								displayRecipe = false

							end

					end

				elseif (CurrentProfession == BTS["Engineering"]) then

					if (CurrentCheck == BTS["Gnomish Engineering"]) or
						(CurrentCheck == BTS["Goblin Engineering"]) then

							if (CurrentCheck ~= CurrentSpeciality ) then

								displayRecipe = false

							end

					end

				elseif (CurrentProfession == BTS["Leatherworking"]) then

					if (CurrentCheck == BTS["Dragonscale Leatherworking"]) or
						(CurrentCheck == BTS["Elemental Leatherworking"]) or
						(CurrentCheck == BTS["Tribal Leatherworking"]) then

							if (CurrentCheck ~= CurrentSpeciality ) then

								displayRecipe = false

							end

					end

				elseif (CurrentProfession == BTS["Tailoring"]) then

					if (CurrentCheck == BTS["Mooncloth Tailoring"]) or
						(CurrentCheck == BTS["Shadoweave Tailoring"]) or
						(CurrentCheck == BTS["Spellfire Tailoring"]) then

							if (CurrentCheck ~= CurrentSpeciality ) then

								displayRecipe = false

							end

					end

				end

			end

		end

	end
	return displayRecipe

end

-- Returns the number of recipes missing

function ARL:GetNumMissingRecipes()

	return ARL_NumberOfRecipes - ARL_FoundRecipes

end

-- Scans the first 24 entries in the spellbook to find which profession speciality someone is (assumption is that it will be within the first 24 because of the general tab)

function ARL:GetTradeSpeciality(CurrentProfession)

local index = 1

	while true do

		local spellName, _ = GetSpellName(index, BOOKTYPE_SPELL)

		if ( not spellName ) or ( index == 25 ) then

			return ""
			--break

		end

		if ( CurrentProfession == BTS["Alchemy"]) then

			if ( spellName == BTS["Elixir Master"]) or
				( spellName == BTS["Potion Master"]) or
				( spellName == BTS["Transmutation Master"]) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Blacksmithing"]) then

			if ( spellName == BTS["Armorsmith"]) or
				( spellName == BTS["Master Axesmith"]) or
				( spellName == BTS["Master Hammersmith"]) or
				( spellName == BTS["Master Swordsmith"]) or
				( spellName == BTS["Weaponsmith"]) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Engineering"]) then

			if ( spellName == BTS["Gnomish Engineer"]) or
				( spellName == BTS["Goblin Engineer"]) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Leatherworking"]) then

			if ( spellName == BTS["Dragonscale Leatherworking"]) or
				( spellName == BTS["Elemental Leatherworking"]) or
				( spellName == BTS["Tribal Leatherworking"]) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Tailoring"]) then

			if ( spellName == BTS["Mooncloth Tailoring"]) or
				( spellName == BTS["Shadoweave Tailoring"]) or
				( spellName == BTS["Spellfire Tailoring"]) then

				return spellName

			end

		end

		index = index + 1

	end

end

--[[

	Output functions

]]--

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function ARL:printMissingSkill(RecipeName)

	DEFAULT_CHAT_FRAME:AddMessage(Crayon:Red( RecipeName ) .. Crayon:White( L["MissingFromDB"]))

end

-- Prints out to chat the recipe and where it can be found.

function ARL:PrintRecipeInfo(RecipeName)

	if (ARL_MissingRecipeListing[ RecipeName ][ "Acquire" ] ~= nil) then

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple( L["MissingRecipePrefix"]) .. Crayon:Green( RecipeName .. " - [" .. ARL_MissingRecipeListing[ RecipeName ][ "Level" ] .. "]") .. "\n    - " .. ARL_MissingRecipeListing[ RecipeName ][ "Acquire" ])

	else

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple( L["MissingRecipePrefix"]) .. Crayon:Green( RecipeName .. " - [" .. ARL_MissingRecipeListing[ RecipeName ][ "Level" ] .. "]"))

	end

end

-- Combines a rep level and faction into a single string

function ARL:ARL_AddReputation1(RepLevel, Faction)

	return L["REPUTATIONOUTPUT1"]:format( RepLevel, Faction )

end

-- Combines a rep level and two factions into a single string

function ARL:ARL_AddReputation2(RepLevel, Faction1, Faction2)

	return L["REPUTATIONOUTPUT2"]:format( RepLevel, Faction1, RepLevel, Faction2 )

end

-- Identifies that a scan is occuring in chat

function ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

	if ( CurrentSpeciality == "" ) then

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Copper(ARLTitle))
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScan"]:format(CurrentProfession, CurrentProfessionLevel)))

	else

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScanSpecial"]:format(CurrentProfession, CurrentSpeciality, CurrentProfessionLevel)))
	
	end

end

-- Displays a summary of known recipes, total recipes and percentages.

function ARL:PrintRecipeListSummary()

	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["RecipeListSummary"]:format(ARL_FoundRecipes, ARL_NumberOfRecipes, math.floor( ARL_FoundRecipes / ARL_NumberOfRecipes * 100 ), ARL:GetNumMissingRecipes() ) ) )

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedList, CurrentProfession, CurrentSpeciality)

	-- Parse the ARL_MissingRecipeListing, printing out the entries
	if ( ARL_MissingRecipeListing ~= nil ) then

		-- No sorting at all
		if ( SortedList == nil ) then

			local RecipeName = next(ARL_MissingRecipeListing, nil)

			while ( RecipeName ~= nil ) do

				if ( ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

					ARL:PrintRecipeInfo(RecipeName)

				end

				-- Move on to the next entry in the table
				RecipeName = next(ARL_MissingRecipeListing, RecipeName)
	
			end

		else

			for i, RecipeName in ipairs(SortedList) do

				if ( ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

					ARL:PrintRecipeInfo(RecipeName)

				end

			end

		end

	end

	ARL:PrintRecipeListSummary()

end

--[[

	Sorting Functions

]]--

-- Returns true if a Recipe1 has a lower skill level than Recipe2

local function ARL_SortMissingSkill(Recipe1, Recipe2)

	return ARL_MissingRecipeListing[ Recipe1 ][ "Level" ] < ARL_MissingRecipeListing[ Recipe2 ][ "Level" ]

end

-- Returns true if a Recipe1 come before Recipe2 in the alphabet

local function ARL_SortMissingName(Recipe1, Recipe2)

	return Recipe1 < Recipe2

end

-- Sorts the ARL_MissingRecipeListing with the given sorting function

function ARL:SortMissingRecipes(SortFunction)

	local TempRecipeSort = {}

	-- Get all the indexes of the ARL_MissingRecipeListing
	for n in pairs( ARL_MissingRecipeListing ) do

		table.insert(TempRecipeSort, n)

	end

	-- Sort the indexes according to the function
	table.sort(TempRecipeSort, SortFunction)

	return TempRecipeSort

end 

--[[

	Recipe Array Functions

]]--

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeTradeRecipes(CurrentProfession)

	if CurrentProfession == BTS["Alchemy"] then

		-- Add all alchemy recipes to the table
		ARL:ARL_InitAlchemy()
		
	elseif CurrentProfession == BTS["Blacksmithing"] then
		
		-- Add all blacksmithing recipes to the table
		ARL:ARL_InitBlackSmith()

	elseif CurrentProfession == BTS["Cooking"] then

		-- Add all cooking recipes to the table
		ARL:ARL_InitCooking()

	elseif CurrentProfession == BTS["Engineering"] then
		
		-- Add all engineering recipes to the table
		ARL:ARL_InitEngineering()
	
	elseif CurrentProfession == BTS["First Aid"] then

		-- Add all first aid recipes to the table
		ARL:ARL_InitFirstAid()

	elseif CurrentProfession == BTS["Leatherworking"] then

		-- Add all leatherworking recipes to the table		
		ARL:ARL_InitLeatherWorking()

	elseif CurrentProfession == BTS["Poisons"] then

		-- Add all rogue poisons recipes to the table
		ARL:ARL_InitRoguePoison()

	elseif CurrentProfession == BTS["Mining"] then

		-- Add all smelting recipes to the table
		ARL:ARL_InitSmelting()

	elseif CurrentProfession == BTS["Tailoring"] then

		-- Add all tailoring recipes to the table
		ARL:ARL_InitTailoring()

	-- Burning Crusade Professions
	elseif CurrentProfession == BTS["Jewelcrafting"] then

		-- Add all jewelcrafting recipes to the table
		ARL:ARL_InitJewelcrafting()

	else

		DEFAULT_CHAT_FRAME:AddMessage( L["UnknownTradeSkill"]:format( CurrentProfession ) )
		
	end

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeCraftRecipes(CurrentProfession)

	local CurrentProfessionLevel

	if CurrentProfession == BTS["Enchanting"] then

		-- Get the current level of the craft.
		CurrentProfessionLevel = _G["CraftRankFrame"]:GetValue() --Better way to do this?

		-- Add all enchanting recipes to the table
		ARL:ARL_InitEnchanting()

	elseif CurrentProfession == L["Beast Training"] then

		-- Player level = profession level for beast training
		CurrentProfessionLevel = UnitLevel("player")

		-- Add all beast training recipes to the table
		ARL:ARL_InitBeastTraining()

	else

		CurrentProfessionLevel = 0
		DEFAULT_CHAT_FRAME:AddMessage(L["UnknownTradeSkill"]:format(CurrentProfession))

	end

	return CurrentProfessionLevel

end

--[[

	Scanning functions

]]--

-- Scans your recipe book for Trade Skill Recipes

function ARL:ScanTradeSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumTradeSkills() do

		local skillName, RecipeHeader, _, _ = GetTradeSkillInfo(i)

		-- Ignore all trade skill headers
		if (RecipeHeader ~= "header") then

			ARL:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandTradeSkillSubClass(i)
		
		end

	end
	
end

-- Scans the ARL_RecipeListing adding all missing recipes to the ARL_MissingRecipeListing

function ARL:ScanMissingRecipes()

	-- Parse the recipe listing table, adding entries to the ARL_MissingRecipeListing table
	if ( ARL_RecipeListing ~= nil ) then

		local RecipeName = next(ARL_RecipeListing, nil)

			while (RecipeName ~= nil) do

				-- If the recipe is not known then print out the info
				if ( ARL_RecipeListing[ RecipeName ][ "Known" ] == false ) then

					ARL_MissingRecipeListing[ RecipeName ] = {}
					ARL_MissingRecipeListing[ RecipeName ][ "Level" ] = ARL_RecipeListing[ RecipeName ][ "Level" ]
					ARL_MissingRecipeListing[ RecipeName ][ "Acquire" ] = ARL_RecipeListing[ RecipeName ][ "Acquire" ]
					ARL_MissingRecipeListing[ RecipeName ][ "Speciality" ] = ARL_RecipeListing[ RecipeName ][ "Speciality" ]

				end

				-- Move on to the next entry in the table
				RecipeName = next(ARL_RecipeListing, RecipeName)
	
			end

	end

	-- Done with RecipeList now, so I can empty the table to free up memory now
	ARL_ResetRecipeList()

end

-- Scans your recipe book for Craft Skill Recipes (enchanting is handled differently than other trade skills)

function ARL:ScanCraftSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		local skillName, _, RecipeHeader, _, isExpanded, _, _ = GetCraftInfo(i)

		-- Ignore all trade skill headers
		if (RecipeHeader ~= "header") then

			ARL:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandCraftSkillLine(i)

		end

	end

end

-- Scans your recipe book for beast training skills

function ARL:ScanBeastTraining(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, skillRank, _, _, _, _, _ = GetCraftInfo(i) -- Don't need a lot of this information, what to do with it?

		local FullSkillName = skillName .. " (" .. skillRank .. ")"

		ARL:CheckRecipe(FullSkillName)

	end

end

-- Main logic for add-on, will call all sub-functions

function ARL:AckisRecipeList_Command()

	local CurrentProfession, CurrentProfessionLevel, CurrentSpeciality, SortedRecipeIndex

	if ( ARL_SkillType == nil ) then

		DEFAULT_CHAT_FRAME:AddMessage(L["OpenTradeSkillWindow"])

	-- Trade type skills
	elseif (ARL_SkillType == "Trade") then

		-- Get the name of the current trade skill opened, along with the current level of the skill. 
		CurrentProfession, CurrentProfessionLevel, _ = GetTradeSkillLine()

		CurrentSpeciality = ARL:GetTradeSpeciality(CurrentProfession)

		ARL_InitializeTradeRecipes(CurrentProfession)

		if (CurrentProfession == BTS["Poisons"]) then

			-- Player level = profession level for rogue poisons
			CurrentProfessionLevel = UnitLevel("player")

		end

		ARL:ScanTradeSkills(CurrentProfession)

		ARL:ScanMissingRecipes()

		if ( self.db.profile.sorting == "Skill" ) then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingSkill)

		elseif ( self.db.profile.sorting == "Name" ) then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingName)

		end

		if ( AckisRecipeList.db.profile.usegui ) then

			ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		else

			ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)
			ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		end

	-- Craft type skills
	elseif ( ARL_SkillType == "Craft" ) then

		-- Get the name of the current craft.
		CurrentProfession = GetCraftName()

		CurrentProfessionLevel = ARL_InitializeCraftRecipes(CurrentProfession)

		CurrentSpeciality = ARL:GetTradeSpeciality(CurrentProfession)

		if CurrentProfession == BTS["Enchanting"] then

			-- Scan for missing enchanting recipes
			ARL:ScanCraftSkills(CurrentProfession)

		elseif CurrentProfession == L["Beast Training"] then

			-- Scan for missing beast training
			ARL:ScanBeastTraining(CurrentProfession)

		end

		ARL:ScanMissingRecipes()

		if ( self.db.profile.sorting == "Skill" ) then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingSkill)

		elseif ( self.db.profile.sorting == "Name" ) then

			SortedRecipeIndex = ARL:SortMissingRecipes(ARL_SortMissingName)

		end

		if ( AckisRecipeList.db.profile.usegui ) then

			ARL:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		else

			ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)
			ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		end

	end

end

